==> haskell-butcher-1.3.3.2-389-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-9ta2YzkedSN7mcTNHBnG8q
key:                  butcher-1.3.3.2-9ta2YzkedSN7mcTNHBnG8q
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  31b635d333cca8d4ca03cb52f75154ca
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-9ta2YzkedSN7mcTNHBnG8q
depends:
    base-4.17.2.1 bifunctors-5.6-10TuipejvSl5iLwFVhSywc
    containers-0.6.7 deque-0.4.4.1-EGxpTb68Vm79pEFhhyxHGG
    extra-1.7.16-EuapY98rdrN25pzQYLq3T2 free-5.2-6pWJt0CG6431iIw6uoA2Ur
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO mtl-2.2.2
    multistate-0.8.0.4-Dxk9oDGJD15BwEcTmdFFHl pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-butcher-1.3.3.2-390-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-GGMO6dXaENmIsZl0sfTG8x
key:                  butcher-1.3.3.2-GGMO6dXaENmIsZl0sfTG8x
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  44dc2060d0e723379e43d455aa52f944
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-GGMO6dXaENmIsZl0sfTG8x
depends:
    base-4.17.2.1 bifunctors-5.6-10TuipejvSl5iLwFVhSywc
    containers-0.6.7 deque-0.4.4.1-CkyASydtQM5EOvpeQJtr6d
    extra-1.7.16-EuapY98rdrN25pzQYLq3T2 free-5.2-6pWJt0CG6431iIw6uoA2Ur
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO mtl-2.2.2
    multistate-0.8.0.4-Dxk9oDGJD15BwEcTmdFFHl pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
